[Libreoffice-commits] core.git: bean/native framework/qa framework/source odk/examples sfx2/source uui/source vbahelper/source

Andrea Gelmini andrea.gelmini at gelma.net
Sun Jan 14 15:24:37 UTC 2018


 bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c                                |    2 +-
 framework/qa/complex/dispatches/checkdispatchapi.java                                        |    2 +-
 framework/source/accelerators/presethandler.cxx                                              |    2 +-
 framework/source/accelerators/storageholder.cxx                                              |    6 +++---
 framework/source/dispatch/closedispatcher.cxx                                                |    4 ++--
 framework/source/dispatch/dispatchprovider.cxx                                               |    2 +-
 framework/source/fwe/xml/saxnamespacefilter.cxx                                              |    2 +-
 framework/source/fwi/jobs/configaccess.cxx                                                   |    2 +-
 framework/source/jobs/jobdata.cxx                                                            |   10 +++++-----
 framework/source/jobs/joburl.cxx                                                             |    2 +-
 framework/source/layoutmanager/layoutmanager.cxx                                             |    2 +-
 framework/source/services/pathsettings.cxx                                                   |    2 +-
 framework/source/uielement/popuptoolbarcontroller.cxx                                        |    4 ++--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java                 |    6 +++---
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java                |    4 ++--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java                    |    2 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/nativelib/windows/nativeview.c     |    2 +-
 odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java |    2 +-
 sfx2/source/bastyp/fltfnc.cxx                                                                |    2 +-
 sfx2/source/dialog/backingcomp.cxx                                                           |    2 +-
 uui/source/iahndl.cxx                                                                        |    2 +-
 vbahelper/source/vbahelper/vbadocumentbase.cxx                                               |    2 +-
 22 files changed, 33 insertions(+), 33 deletions(-)

New commits:
commit cfffb09b3d6d46c500e3be3fe601a4ff6944d40e
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Sun Jan 14 12:50:47 2018 +0100

    Fix typos
    
    Change-Id: I2a578961837076ebce3c1fb2681b0785d1d490ac
    Reviewed-on: https://gerrit.libreoffice.org/47857
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c b/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
index d425d5e065e8..dd19fe7931b8 100644
--- a/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
+++ b/bean/native/win32/com_sun_star_comp_beans_LocalOfficeWindow.c
@@ -126,7 +126,7 @@ JNIEXPORT jlong JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNative
     awt.FreeDrawingSurface(ds);
 
     /* Register own window procedure
-       Do it one times only! Otherwhise
+       Do it one times only! Otherwise
        multiple instances will be registered
        and calls on such construct produce
        a stack overflow.
diff --git a/framework/qa/complex/dispatches/checkdispatchapi.java b/framework/qa/complex/dispatches/checkdispatchapi.java
index 32786e858364..cceabb4f436c 100644
--- a/framework/qa/complex/dispatches/checkdispatchapi.java
+++ b/framework/qa/complex/dispatches/checkdispatchapi.java
@@ -193,7 +193,7 @@ public class checkdispatchapi
     @Test public void checkInterceptorLifeTime() throws Exception
     {
         // Note: It's important for the following test, that aInterceptor will be hold alive by the uno reference
-        // xInterceptor. Otherwhise we can't check some internal states of aInterceptor at the end of this method, because
+        // xInterceptor. Otherwise we can't check some internal states of aInterceptor at the end of this method, because
         // it was already killed .-)
 
         Interceptor aInterceptor = new Interceptor(m_xMSF);
diff --git a/framework/source/accelerators/presethandler.cxx b/framework/source/accelerators/presethandler.cxx
index 3d6047dadaae..b5b309150fd6 100644
--- a/framework/source/accelerators/presethandler.cxx
+++ b/framework/source/accelerators/presethandler.cxx
@@ -761,7 +761,7 @@ css::uno::Reference< css::embed::XStorage > PresetHandler::impl_openLocalizedPat
 
     // it doesn't matter, if there is a locale fallback or not
     // If creation of storages is allowed, we do it anyway.
-    // Otherwhise we have no acc config at all, which can make other trouble.
+    // Otherwise we have no acc config at all, which can make other trouble.
     OUString sLocalizedPath;
     sLocalizedPath  = sPath;
     sLocalizedPath += "/";
diff --git a/framework/source/accelerators/storageholder.cxx b/framework/source/accelerators/storageholder.cxx
index 7ea3d2f76ce2..0b29d038d1b2 100644
--- a/framework/source/accelerators/storageholder.cxx
+++ b/framework/source/accelerators/storageholder.cxx
@@ -110,7 +110,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
         aReadLock.reset();
 
         // If we found an already open storage ... we must increase
-        // its use count. Otherwhise it will may be closed to early :-)
+        // its use count. Otherwise it will may be closed to early :-)
         TPath2StorageInfo::iterator pCheck = m_lStorages.find(sCheckPath);
         TStorageInfo*               pInfo  = nullptr;
         if (pCheck != m_lStorages.end())
@@ -429,7 +429,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openSubStorageWithFal
 
     // c) try it readonly
     //    don't catch exception here! Outside code wish to know, if operation failed or not.
-    //    Otherwhise they work on NULL references ...
+    //    Otherwise they work on NULL references ...
     sal_Int32 eNewMode = (eOpenMode & ~css::embed::ElementModes::WRITE);
     css::uno::Reference< css::embed::XStorage > xSubStorage = xBaseStorage->openStorageElement(sSubStorage, eNewMode);
     if (xSubStorage.is())
@@ -468,7 +468,7 @@ css::uno::Reference< css::io::XStream > StorageHolder::openSubStreamWithFallback
 
     // c) try it readonly
     //    don't catch exception here! Outside code wish to know, if operation failed or not.
-    //    Otherwhise they work on NULL references ...
+    //    Otherwise they work on NULL references ...
     sal_Int32 eNewMode = (eOpenMode & ~css::embed::ElementModes::WRITE);
     css::uno::Reference< css::io::XStream > xSubStream = xBaseStorage->openStreamElement(sSubStream, eNewMode);
     if (xSubStream.is())
diff --git a/framework/source/dispatch/closedispatcher.cxx b/framework/source/dispatch/closedispatcher.cxx
index ca9ce2d9aefb..c7e5279ba46e 100644
--- a/framework/source/dispatch/closedispatcher.cxx
+++ b/framework/source/dispatch/closedispatcher.cxx
@@ -139,7 +139,7 @@ void SAL_CALL CloseDispatcher::dispatchWithNotification(const css::util::URL&
 
     // This reference indicates, that we was already called before and
     // our asynchronous process was not finished yet.
-    // We have to reject double calls. Otherwhise we risk,
+    // We have to reject double calls. Otherwise we risk,
     // that we try to close an already closed resource ...
     // And its no problem to do nothing then. The UI user will try it again, if
     // non of these jobs was successfully.
@@ -320,7 +320,7 @@ IMPL_LINK_NOARG(CloseDispatcher, impl_asyncCallback, LinkParamNone*, void)
             bTerminateApp = true;
     }
 
-    // d) Otherwhise we have to: close all views to the same document, close the
+    // d) Otherwise we have to: close all views to the same document, close the
     //    document inside our own frame and decide then again, what has to be done!
     else
     {
diff --git a/framework/source/dispatch/dispatchprovider.cxx b/framework/source/dispatch/dispatchprovider.cxx
index 8a4e3aa48a92..177ef42a302a 100644
--- a/framework/source/dispatch/dispatchprovider.cxx
+++ b/framework/source/dispatch/dispatchprovider.cxx
@@ -393,7 +393,7 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_queryFrame
         {
             // Attention: Found target is our own owner frame!
             // Don't ask him for his dispatcher. We know it already - it's our self dispatch helper.
-            // Otherwhise we can start a never ending recursiv call. Why?
+            // Otherwise we can start a never ending recursiv call. Why?
             // Somewere called our owner frame - he called some interceptor objects - and may by this dispatch provider
             // is called. If wa use queryDispatch() on our owner frame again - we start this call stack again ... and again.
             if (xFoundFrame==xFrame)
diff --git a/framework/source/fwe/xml/saxnamespacefilter.cxx b/framework/source/fwe/xml/saxnamespacefilter.cxx
index fc498248c987..9f24552d3232 100644
--- a/framework/source/fwe/xml/saxnamespacefilter.cxx
+++ b/framework/source/fwe/xml/saxnamespacefilter.cxx
@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-/** Attention: stl headers must(!) be included at first. Otherwhise it can make trouble
+/** Attention: stl headers must(!) be included at first. Otherwise it can make trouble
                with solaris headers ...
 */
 #include <vector>
diff --git a/framework/source/fwi/jobs/configaccess.cxx b/framework/source/fwi/jobs/configaccess.cxx
index 7ce56e433e38..b641982ca300 100644
--- a/framework/source/fwi/jobs/configaccess.cxx
+++ b/framework/source/fwi/jobs/configaccess.cxx
@@ -170,7 +170,7 @@ void ConfigAccess::close()
                     aReadLock.unlock();
 
     @attention  During this time it's not allowed to call the methods open() or close()!
-                Otherwhise you will change your own referenced config access. Anything will
+                Otherwise you will change your own referenced config access. Anything will
                 be possible then.
 
     @return A c++(!) reference to the uno instance of the configuration access point.
diff --git a/framework/source/jobs/joburl.cxx b/framework/source/jobs/joburl.cxx
index fd30218dd954..64b4745ede9a 100644
--- a/framework/source/jobs/joburl.cxx
+++ b/framework/source/jobs/joburl.cxx
@@ -227,7 +227,7 @@ bool JobURL::implst_split( /*IN*/  const OUString& sPart           ,
     bool bPartFound = sPart.matchIgnoreAsciiCaseAsciiL(pPartIdentifier,nPartLength);
 
     // If it exist - we can split the part and return sal_True.
-    // Otherwhise we do nothing and return sal_False.
+    // Otherwise we do nothing and return sal_False.
     if (bPartFound)
     {
         // But may the part has optional arguments - separated by a "?".
diff --git a/framework/source/layoutmanager/layoutmanager.cxx b/framework/source/layoutmanager/layoutmanager.cxx
index 3c43acb8e9d4..3b3aa1173eba 100644
--- a/framework/source/layoutmanager/layoutmanager.cxx
+++ b/framework/source/layoutmanager/layoutmanager.cxx
@@ -910,7 +910,7 @@ void LayoutManager::implts_backupProgressBarWrapper()
     m_xProgressBarBackup = m_aProgressBarElement.m_xUIElement;
 
     // remove the relation between this old progress bar and our old status bar.
-    // Otherwhise we work on disposed items ...
+    // Otherwise we work on disposed items ...
     // The internal used ProgressBarWrapper can handle a NULL reference.
     if ( m_xProgressBarBackup.is() )
     {
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index ed73a08fae41..4122292f37b5 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -821,7 +821,7 @@ css::uno::Sequence< sal_Int32 > PathSettings::impl_mapPathName2IDList(const OUSt
     OUString sWriteProp    = sPath+POSTFIX_WRITE_PATH;
 
     // Attention: The default set of IDs is fix and must follow these schema.
-    // Otherwhise the outside code ant work for new added properties.
+    // Otherwise the outside code ant work for new added properties.
     // Why?
     // The outside code must fire N events for every changed property.
     // And the knowing about packaging of variables of the structure PathInfo
diff --git a/framework/source/uielement/popuptoolbarcontroller.cxx b/framework/source/uielement/popuptoolbarcontroller.cxx
index cb41c774fc10..22bfc8fdc969 100644
--- a/framework/source/uielement/popuptoolbarcontroller.cxx
+++ b/framework/source/uielement/popuptoolbarcontroller.cxx
@@ -694,7 +694,7 @@ void NewToolbarController::functionExecuted( const OUString &rCommand )
     it return the existing state of the given URL in the popupmenu of this toolbox control.
 
     If the given URL can be located as an action command of one menu item of the
-    popup menu of this control, we return sal_True. Otherwhise we return sal_False.
+    popup menu of this control, we return sal_True. Otherwise we return sal_False.
     Further we return a fallback URL, in case we have to return sal_False. Because
     the outside code must select a valid item of the popup menu every time ...
     and we define it here. By the way this method was written to handle
@@ -717,7 +717,7 @@ void NewToolbarController::functionExecuted( const OUString &rCommand )
                 contains the image of the menu for the URL.
 
     @return sal_True - if URL could be located as an item of the popup menu.
-            sal_False - otherwhise.
+            sal_False - otherwise.
 */
 bool Impl_ExistURLInMenu(
     const css::uno::Reference< css::awt::XPopupMenu > &rPopupMenu,
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
index b8b3e4f7bfa2..0678ee009f1d 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/CustomizeView.java
@@ -169,7 +169,7 @@ public class CustomizeView extends    JPanel
      * Note: Because we are listener status events too - hopefully
      * we get a notification, if toggling was successfully or not.
      * We use this information to update our check boxes again.
-     * But such update doesn't force (hopefully) an action event. Otherwhise
+     * But such update doesn't force (hopefully) an action event. Otherwise
      * we can produce a never ending recursion!
      */
     private class ClickListener implements ActionListener,
@@ -248,7 +248,7 @@ public class CustomizeView extends    JPanel
          *
          * @param aEvent
          *          describes the source which fire this event
-         *          Must be our internal saved frame. Otherwhise
+         *          Must be our internal saved frame. Otherwise
          *          somewhere know us without a registration ...
          */
         public void disposing(com.sun.star.lang.EventObject aEvent)
@@ -264,7 +264,7 @@ public class CustomizeView extends    JPanel
 
     /**
      * If this java application shutdown - we must cancel all current existing
-     * listener connections. Otherwhise the office will run into some
+     * listener connections. Otherwise the office will run into some
      * DisposedExceptions if it tries to use these forgotten listener references.
      * And of course it can die doing that.
      * We are registered at a central object to be informed if the VM will exit.
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
index fee367d125b2..e50686c38cf6 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
@@ -364,7 +364,7 @@ public class FunctionHelper
 
             // pass the window the frame as his new container window.
             // It's necessary to do it first  - before you call anything else there.
-            // Otherwhise the frame throws some exceptions for "uninitialized state".
+            // Otherwise the frame throws some exceptions for "uninitialized state".
             xFrame.initialize( xWindow );
 
             // Insert the new frame in desktop hierarchy.
@@ -440,7 +440,7 @@ public class FunctionHelper
      *                      (Note: Deregistration is part of this listener himself!)
      *
      * @return  [XDispatch] It's the used dispatch object and can be used for deregistration of an optional listener.
-     *                      Otherwhise caller can ignore it.
+     *                      Otherwise caller can ignore it.
      */
     public static com.sun.star.frame.XDispatch execute(com.sun.star.frame.XFrame          xFrame     ,
                                                        com.sun.star.util.URL              aURL       ,
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
index 3131332e7d53..92ae178adc59 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusView.java
@@ -239,7 +239,7 @@ public class StatusView extends    JPanel
 
     /**
      * If this java application shutdown - we must cancel all current existing
-     * listener connections. Otherwhise the office will run into some
+     * listener connections. Otherwise the office will run into some
      * DisposedExceptions if it tries to use these forgotten listener references.
      * And of course it can die doing that.
      * We are registered at a central object to be informed if the VM will exit.
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/nativelib/windows/nativeview.c b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/nativelib/windows/nativeview.c
index 750364c01cce..b7b13d6c640d 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/nativelib/windows/nativeview.c
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/nativelib/windows/nativeview.c
@@ -115,7 +115,7 @@ JNIEXPORT jlong JNICALL Java_NativeView_getNativeWindow
     awt.FreeDrawingSurface(ds);
 
     /* Register own window procedure
-       Do it one times only! Otherwhise
+       Do it one times only! Otherwise
        multiple instances will be registered
        and calls on such construct produce
        a stack overflow.
diff --git a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
index 2e83f4af76e1..cc4d5c5eafc1 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
@@ -216,7 +216,7 @@ public class AsciiReplaceFilter
         * For external user of us we must provide our internal filter name
         * (which is registered inside configuration package TypeDetection).
         * User will be able then to ask there for further information about us.
-        * Otherwhise we must implement a full featured XPropertySet...
+        * Otherwise we must implement a full featured XPropertySet...
         *
         * @return our internal filter name of configuration
         */
diff --git a/sfx2/source/bastyp/fltfnc.cxx b/sfx2/source/bastyp/fltfnc.cxx
index 2899d4f66558..ba7cc8ac9330 100644
--- a/sfx2/source/bastyp/fltfnc.cxx
+++ b/sfx2/source/bastyp/fltfnc.cxx
@@ -398,7 +398,7 @@ ErrCode  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, std:
     try
     {
         // open the stream one times only ...
-        // Otherwhise it will be tried more than once and show the same interaction more than once ...
+        // Otherwise it will be tried more than once and show the same interaction more than once ...
 
         OUString sURL( rMedium.GetURLObject().GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
         uno::Reference< io::XInputStream > xInStream = rMedium.GetInputStream();
diff --git a/sfx2/source/dialog/backingcomp.cxx b/sfx2/source/dialog/backingcomp.cxx
index 37a2348cd11f..76086dc404c7 100644
--- a/sfx2/source/dialog/backingcomp.cxx
+++ b/sfx2/source/dialog/backingcomp.cxx
@@ -698,7 +698,7 @@ void SAL_CALL BackingComp::keyPressed( /*IN*/ const css::awt::KeyEvent&  )
 void SAL_CALL BackingComp::keyReleased( /*IN*/ const css::awt::KeyEvent& )
 {
     /* Attention
-        Please use keyPressed() instead of this method. Otherwhise it would be possible, that
+        Please use keyPressed() instead of this method. Otherwise it would be possible, that
         - a key input may be first switch to the backing mode
         - and this component register itself as key listener too
         - and it's first event will be a keyRealeased() for the already well known event, which switched to the backing mode!
diff --git a/uui/source/iahndl.cxx b/uui/source/iahndl.cxx
index e2ce02c659d5..51af635a24bf 100644
--- a/uui/source/iahndl.cxx
+++ b/uui/source/iahndl.cxx
@@ -1088,7 +1088,7 @@ UUIInteractionHelper::handleGenericErrorRequest(
         getContinuations(rContinuations, &xApprove, &xAbort);
 
         // Note: It's important to convert the transported long to the
-        // required  unsigned long value. Otherwhise using as flag field
+        // required  unsigned long value. Otherwise using as flag field
         // can fail ...
         ErrCode  nError(nErrorCode);
         bool bWarning = !nError.IgnoreWarning();
diff --git a/vbahelper/source/vbahelper/vbadocumentbase.cxx b/vbahelper/source/vbahelper/vbadocumentbase.cxx
index f9ba17d6ee36..1a2d5049d897 100644
--- a/vbahelper/source/vbahelper/vbadocumentbase.cxx
+++ b/vbahelper/source/vbahelper/vbadocumentbase.cxx
@@ -178,7 +178,7 @@ VbaDocumentBase::Close( const uno::Any &rSaveArg, const uno::Any &rFileArg,
             try {
                 // If close is not supported by this model - try to dispose it.
                 // But if the model disagree with a reset request for the modify state
-                // we shouldn't do so. Otherwhise some strange things can happen.
+                // we shouldn't do so. Otherwise some strange things can happen.
                 uno::Reference< lang::XComponent > xDisposable ( xModel, uno::UNO_QUERY_THROW );
                 xDisposable->dispose();
             }


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/jobs/jobdata.cxx b/framework/source/jobs/jobdata.cxx
index 13f23feafe8f..d6855e0603b1 100644
--- a/framework/source/jobs/jobdata.cxx
+++ b/framework/source/jobs/jobdata.cxx
@@ -109,7 +109,7 @@ JobData::~JobData()
 void JobData::setAlias( const OUString& sAlias )
 {
     SolarMutexGuard g;
     // delete all old information! Otherwhise we mix it with the new one ...
     impl_reset();
 
     // take over the new information
@@ -175,7 +175,7 @@ void JobData::setAlias( const OUString& sAlias )
 void JobData::setService( const OUString& sService )
 {
     SolarMutexGuard g;
     // delete all old information! Otherwhise we mix it with the new one ...
     impl_reset();
     // take over the new information
     m_sService = sService;
@@ -291,7 +291,7 @@ void JobData::setResult( const JobResult& aResult )
     @short  set a new environment descriptor for this job
     @descr  It must(!) be done every time this container is initialized
             with new job datas e.g.: setAlias()/setEvent()/setService() ...
-            Otherwhise the environment will be unknown!
+            Otherwise the environment will be unknown!
  */
 void JobData::setEnvironment( EEnvironment eEnvironment )
 {
@@ -446,7 +446,7 @@ bool isEnabled( const OUString& sAdminTime ,
 {
     /*Attention!
         To prevent interpreting of TriGraphs inside next const string value,
-        we have to encode all '?' signs. Otherwhise e.g. "??-" will be translated
+        we have to encode all '?' signs. Otherwise e.g. "??-" will be translated
         to "~" ...
      */
     WildCard aISOPattern("\?\?\?\?-\?\?-\?\?*");
@@ -569,7 +569,7 @@ std::vector< OUString > JobData::getEnabledJobsForEvent( const css::uno::Referen
     @short      reset all internal structures
     @descr      If someone recycles this instance, he can switch from one
                 using mode to another one. But then we have to reset all currently
-                used information. Otherwhise we mix it and they can make trouble.
+                used information. Otherwise we mix it and they can make trouble.
 
                 But note: that does not set defaults for internal used members, which
                 does not relate to any job property! e.g. the reference to the global
@@ -109,7 +109,7 @@ JobData::~JobData()
 {
     SolarMutexGuard g;
-    // delete all old information! Otherwhise we mix it with the new one ...
+    // delete all old information! Otherwise we mix it with the new one ...
     impl_reset();
 
@@ -175,7 +175,7 @@ void JobData::setAlias( const OUString& sAlias )
 {
     SolarMutexGuard g;
-    // delete all old information! Otherwhise we mix it with the new one ...
+    // delete all old information! Otherwise we mix it with the new one ...
     impl_reset();
     // take over the new information